@@ -41,6 +41,8 @@ pub struct SourceOverride {
     vcs_git: Option<String>,
     vcs_browser: Option<String>,
     build_depends: Option<Vec<String>>,
+    build_depends_arch: Option<Vec<String>>,
+    build_depends_indep: Option<Vec<String>>,
     build_depends_excludes: Option<Vec<String>>,
 }
 
@@ -52,6 +54,8 @@ impl SourceOverride {
         vcs_git: Option<String>,
         vcs_browser: Option<String>,
         build_depends: Option<Vec<String>>,
+        build_depends_arch: Option<Vec<String>>,
+        build_depends_indep: Option<Vec<String>>,
         build_depends_excludes: Option<Vec<String>>,
     ) -> Self {
         Self {
@@ -61,6 +65,8 @@ impl SourceOverride {
             vcs_git,
             vcs_browser,
             build_depends,
+            build_depends_arch,
+            build_depends_indep,
             build_depends_excludes,
         }
     }
@@ -74,6 +80,9 @@ pub struct PackageOverride {
     recommends: Option<Vec<String>>,
     suggests: Option<Vec<String>>,
     provides: Option<Vec<String>>,
+    breaks: Option<Vec<String>>,
+    replaces: Option<Vec<String>>,
+    conflicts: Option<Vec<String>>,
     extra_lines: Option<Vec<String>>,
     test_is_broken: Option<bool>,
     test_architecture: Option<Vec<String>>,
@@ -173,6 +182,14 @@ impl Config {
         self.source.as_ref()?.build_depends.as_ref()
     }
 
+    pub fn build_depends_arch(&self) -> Option<&Vec<String>> {
+        self.source.as_ref()?.build_depends_arch.as_ref()
+    }
+
+    pub fn build_depends_indep(&self) -> Option<&Vec<String>> {
+        self.source.as_ref()?.build_depends_indep.as_ref()
+    }
+
     pub fn build_depends_excludes(&self) -> Option<&Vec<String>> {
         self.source.as_ref()?.build_depends_excludes.as_ref()
     }
@@ -218,6 +235,18 @@ impl Config {
         self.with_package(key, |pkg| pkg.provides.as_ref())
     }
 
+    pub fn package_breaks(&self, key: PackageKey) -> Option<&Vec<String>> {
+        self.with_package(key, |pkg| pkg.breaks.as_ref())
+    }
+
+    pub fn package_replaces(&self, key: PackageKey) -> Option<&Vec<String>> {
+        self.with_package(key, |pkg| pkg.replaces.as_ref())
+    }
+
+    pub fn package_conflicts(&self, key: PackageKey) -> Option<&Vec<String>> {
+        self.with_package(key, |pkg| pkg.conflicts.as_ref())
+    }
+
     pub fn package_extra_lines(&self, key: PackageKey) -> Option<&Vec<String>> {
         self.with_package(key, |pkg| pkg.extra_lines.as_ref())
     }
