@@ -1,6 +1,8 @@
+#[cfg(not(test))]
 use std::env::{self, VarError};
 use std::fmt::{self, Write};
 
+#[cfg(not(test))]
 use anyhow::{format_err, Error};
 use semver::Version;
 use textwrap::fill;
@@ -8,6 +10,13 @@ use textwrap::fill;
 use crate::config::{self, Config, PackageKey};
 use crate::errors::*;
 
+#[derive(Default, Debug)]
+pub struct BuildDeps {
+    pub(crate) build_depends: Vec<String>,
+    pub(crate) build_depends_indep: Vec<String>,
+    pub(crate) build_depends_arch: Vec<String>,
+}
+
 pub struct Source {
     name: String,
     section: String,
@@ -15,7 +24,7 @@ pub struct Source {
     maintainer: String,
     uploaders: Vec<String>,
     standards: String,
-    build_deps: Vec<String>,
+    build_deps: BuildDeps,
     vcs_git: String,
     vcs_browser: String,
     homepage: String,
@@ -32,6 +41,9 @@ pub struct Package {
     recommends: Vec<String>,
     suggests: Vec<String>,
     provides: Vec<String>,
+    breaks: Vec<String>,
+    replaces: Vec<String>,
+    conflicts: Vec<String>,
     summary: Description,
     description: Description,
     extra_lines: Vec<String>,
@@ -64,7 +76,27 @@ impl fmt::Display for Source {
         writeln!(f, "Source: {}", self.name)?;
         writeln!(f, "Section: {}", self.section)?;
         writeln!(f, "Priority: {}", self.priority)?;
-        writeln!(f, "Build-Depends: {}", self.build_deps.join(",\n "))?;
+        if !self.build_deps.build_depends.is_empty() {
+            writeln!(
+                f,
+                "Build-Depends: {}",
+                self.build_deps.build_depends.join(",\n ")
+            )?;
+        }
+        if !self.build_deps.build_depends_arch.is_empty() {
+            writeln!(
+                f,
+                "Build-Depends-Arch: {}",
+                self.build_deps.build_depends_arch.join(",\n ")
+            )?;
+        }
+        if !self.build_deps.build_depends_indep.is_empty() {
+            writeln!(
+                f,
+                "Build-Depends-Indep: {}",
+                self.build_deps.build_depends_indep.join(",\n ")
+            )?;
+        }
         writeln!(f, "Maintainer: {}", self.maintainer)?;
         if !self.uploaders.is_empty() {
             writeln!(f, "Uploaders:\n {}", self.uploaders.join(",\n "))?;
@@ -111,6 +143,15 @@ impl fmt::Display for Package {
         if !self.provides.is_empty() {
             writeln!(f, "Provides:\n {}", self.provides.join(",\n "))?;
         }
+        if !self.replaces.is_empty() {
+            writeln!(f, "Replaces:\n {}", self.replaces.join(",\n "))?;
+        }
+        if !self.breaks.is_empty() {
+            writeln!(f, "Breaks:\n {}", self.breaks.join(",\n "))?;
+        }
+        if !self.conflicts.is_empty() {
+            writeln!(f, "Conflicts:\n {}", self.conflicts.join(",\n "))?;
+        }
 
         for line in &self.extra_lines {
             writeln!(f, "{}", line)?;
@@ -182,7 +223,7 @@ impl Source {
         lib: bool,
         maintainer: String,
         uploaders: Vec<String>,
-        build_deps: Vec<String>,
+        build_deps: BuildDeps,
         _requires_root: String,
     ) -> Result<Source> {
         let pkgbase = match name_suffix {
@@ -232,18 +273,42 @@ impl Source {
             self.standards = policy.to_string();
         }
 
-        self.build_deps.extend(
+        self.build_deps.build_depends.extend(
             config
                 .build_depends()
                 .into_iter()
                 .flatten()
                 .map(String::to_string),
         );
+        self.build_deps.build_depends_arch.extend(
+            config
+                .build_depends_arch()
+                .into_iter()
+                .flatten()
+                .map(String::to_string),
+        );
+        self.build_deps.build_depends_indep.extend(
+            config
+                .build_depends_indep()
+                .into_iter()
+                .flatten()
+                .map(String::to_string),
+        );
         let bdeps_ex = config
             .build_depends_excludes()
             .map(Vec::as_slice)
             .unwrap_or(&[]);
-        self.build_deps.retain(|x| !bdeps_ex.contains(x));
+        self.build_deps
+            .build_depends
+            .retain(|x| !bdeps_ex.contains(x));
+
+        self.build_deps
+            .build_depends_arch
+            .retain(|x| !bdeps_ex.contains(x));
+
+        self.build_deps
+            .build_depends_indep
+            .retain(|x| !bdeps_ex.contains(x));
 
         if let Some(homepage) = config.homepage() {
             self.homepage = homepage.to_string();
@@ -348,6 +413,18 @@ impl Package {
         }
         depends.extend(f_deps.into_iter().map(deb_feature));
         depends.extend(o_deps);
+        let mut breaks = vec![];
+        let mut replaces = vec![];
+        if name_suffix.is_some() && feature.is_none() {
+            // B+R needs to be set on "real" package, not virtual ones
+            // constrain by "next" version, so that it is possible to install a newer,
+            // non-suffixed package at the same time
+            let mut next_version = version.clone();
+            next_version.patch += 1;
+            breaks.push(format!("{} (<< {}~)", deb_name(basename), next_version));
+            replaces.push(format!("{} (<< {}~)", deb_name(basename), next_version));
+        }
+        let conflicts = vec![];
 
         Ok(Package {
             name: match feature {
@@ -381,22 +458,12 @@ impl Package {
             recommends,
             suggests,
             provides,
+            breaks,
+            replaces,
+            conflicts,
             summary,
             description,
-            extra_lines: match (name_suffix, feature) {
-                (Some(_), None) => {
-                    // B+R needs to be set on "real" package, not virtual ones
-                    // constrain by "next" version, so that it is possible to install a newer,
-                    // non-suffixed package at the same time
-                    let mut next_version = version.clone();
-                    next_version.patch += 1;
-                    vec![
-                        format!("Replaces: {} (<< {}~)", deb_name(basename), next_version),
-                        format!("Breaks: {} (<< {}~)", deb_name(basename), next_version),
-                    ]
-                }
-                (_, _) => vec![],
-            },
+            extra_lines: vec![],
         })
     }
 
@@ -428,6 +495,9 @@ impl Package {
             recommends: vec!["${cargo:Recommends}".to_string()],
             suggests: vec!["${cargo:Suggests}".to_string()],
             provides,
+            breaks: vec![],
+            replaces: vec![],
+            conflicts: vec![],
             summary,
             description,
             extra_lines: vec![
@@ -495,7 +565,21 @@ impl Package {
             key,
             &f_provides,
         ));
-
+        self.breaks.extend(config::package_field_for_feature(
+            &|x| config.package_breaks(x),
+            key,
+            &f_provides,
+        ));
+        self.replaces.extend(config::package_field_for_feature(
+            &|x| config.package_replaces(x),
+            key,
+            &f_provides,
+        ));
+        self.conflicts.extend(config::package_field_for_feature(
+            &|x| config.package_conflicts(x),
+            key,
+            &f_provides,
+        ));
         self.extra_lines.extend(
             config
                 .package_extra_lines(key)
@@ -581,6 +665,7 @@ pub fn deb_feature_name(name: &str, feature: &str) -> String {
 
 /// Retrieve one of a series of environment variables, and provide a friendly error message for
 /// non-UTF-8 values.
+#[cfg(not(test))]
 fn get_envs(keys: &[&str]) -> Result<Option<String>> {
     for key in keys {
         match env::var(key) {
@@ -597,7 +682,13 @@ fn get_envs(keys: &[&str]) -> Result<Option<String>> {
     Ok(None)
 }
 
+#[cfg(test)]
+pub(crate) fn get_deb_author() -> Result<String> {
+    Ok("Debcargo Test <debcargo@example.com>".to_string())
+}
+
 /// Determine a name and email address from environment variables.
+#[cfg(not(test))]
 pub fn get_deb_author() -> Result<String> {
     let name = get_envs(&["DEBFULLNAME", "NAME"])?.ok_or_else(|| {
         format_err!("Unable to determine your name; please set $DEBFULLNAME or $NAME")
