@@ -4,7 +4,7 @@ use itertools::Itertools;
 use std::cmp;
 use std::fmt;
 
-use crate::config::{testing_ignore_debpolv, Config};
+use crate::config::testing_ignore_debpolv;
 use crate::debian::{self, control::base_deb_name, Package};
 use crate::errors::*;
 
@@ -102,12 +102,12 @@ impl VRange {
         self
     }
 
-    fn to_deb_clause(&self, base: &str, suffix: &str) -> Result<String> {
+    fn to_deb_clause(&self, base: &str, suffix: &str) -> Result<Vec<String>> {
         use debian::dependency::V::*;
         match (&self.ge, &self.lt) {
-            (None, None) => Ok(format!("{}{}", base, suffix)),
-            (Some(ge), None) => Ok(format!("{}{} (>= {}-~~)", base, suffix, ge)),
-            (None, Some(lt)) => Ok(format!("{}{} (<< {}-~~)", base, suffix, lt)),
+            (None, None) => Ok(vec![format!("{}{}", base, suffix)]),
+            (Some(ge), None) => Ok(vec![format!("{}{} (>= {}-~~)", base, suffix, ge)]),
+            (None, Some(lt)) => Ok(vec![format!("{}{} (<< {}-~~)", base, suffix, lt)]),
             (Some(ge), Some(lt)) => {
                 if ge >= lt {
                     debcargo_bail!("bad version range: >= {}, << {}", ge, lt);
@@ -172,7 +172,7 @@ impl VRange {
                             }
                         }
                     })
-                    .join(", "))
+                    .collect())
             }
         }
     }
@@ -293,8 +293,7 @@ fn generate_version_constraints(
 }
 
 /// Translates a Cargo dependency into a Debian package dependency.
-pub fn deb_dep(config: &Config, dep: &Dependency) -> Result<Vec<String>> // result is an AND-clause
-{
+pub fn deb_dep(allow_prerelease_deps: bool, dep: &Dependency) -> Result<Vec<String>> {
     let dep_dashed = base_deb_name(&dep.package_name());
     let mut suffixes = Vec::new();
     if dep.uses_default_features() {
@@ -312,19 +311,23 @@ pub fn deb_dep(config: &Config, dep: &Dependency) -> Result<Vec<String>> // resu
         let base = format!("{}-{}", Package::pkg_prefix(), dep_dashed);
         let mut vr = VRange::new();
         for p in &req.comparators {
-            let op = coerce_unacceptable_predicate(dep, p, config.allow_prerelease_deps)?;
+            let op = coerce_unacceptable_predicate(dep, p, allow_prerelease_deps)?;
             generate_version_constraints(&mut vr, dep, p, op)?;
         }
-        deps.push(vr.to_deb_clause(&base, &suffix)?);
+        deps.extend(vr.to_deb_clause(&base, &suffix)?);
     }
     Ok(deps)
 }
 
-pub fn deb_deps(config: &Config, cdeps: &[Dependency]) -> Result<Vec<String>> // result is an AND-clause
+pub fn deb_deps(allow_prerelease_deps: bool, cdeps: &[Dependency]) -> Result<Vec<String>> // result is an AND-clause
 {
     let mut deps = Vec::new();
     for dep in cdeps {
-        deps.extend(deb_dep(config, dep)?.iter().map(String::to_string));
+        deps.extend(
+            deb_dep(allow_prerelease_deps, dep)?
+                .iter()
+                .map(String::to_string),
+        );
     }
     deps.sort();
     deps.dedup();
