@@ -10,6 +10,7 @@ use std::str::FromStr;
 
 use anyhow::format_err;
 use chrono::{self, Datelike};
+use control::BuildDeps;
 use flate2::read::GzDecoder;
 use flate2::write::GzEncoder;
 use flate2::Compression;
@@ -19,7 +20,9 @@ use tar::{Archive, Builder};
 use tempfile;
 
 use crate::config::{package_field_for_feature, testing_ignore_debpolv, Config, PackageKey};
-use crate::crates::{show_dep, transitive_deps, CrateDepInfo, CrateInfo};
+use crate::crates::{
+    all_dependencies_and_features, show_dep, transitive_deps, CrateDepInfo, CrateInfo,
+};
 use crate::errors::*;
 use crate::util::{self, copy_tree, expect_success, get_transitive_val, traverse_depth};
 
@@ -630,8 +633,8 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         .map(String::as_str)
         .collect();
 
-    let features_with_deps = crate_info.all_dependencies_and_features();
-    let dev_depends = deb_deps(config, &crate_info.dev_dependencies())?;
+    let features_with_deps = all_dependencies_and_features(crate_info.manifest());
+    let dev_depends = deb_deps(config.allow_prerelease_deps, &crate_info.dev_dependencies())?;
     let has_dev_deps = !dev_depends.is_empty();
     log::trace!(
         "features_with_deps: {:?}",
@@ -676,10 +679,14 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
     };
 
     let build_deps = {
-        let rustc = rustc_dep(&crate_info.rust_version(), true);
-        let build_deps = ["debhelper-compat (= 13)", "dh-sequence-cargo"]
-            .iter()
-            .map(|x| x.to_string());
+        let mut build_deps = BuildDeps::default();
+        // these are needed for the clean target
+        build_deps.build_depends.extend(
+            ["debhelper-compat (= 13)", "dh-sequence-cargo"]
+                .iter()
+                .map(|x| x.to_string()),
+        );
+
         // note: please keep this in sync with build_order::dep_features
         let (default_features, default_deps) = transitive_deps(&features_with_deps, "default")?;
         //debcargo_info!("default_features: {:?}", default_features);
@@ -689,22 +696,19 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             PackageKey::feature("default"),
             &default_features,
         );
-        let build_deps_extra = [
-            "cargo:native".into(),
-            rustc.clone(),
-            "libstd-rust-dev".into(),
-        ]
-        .into_iter()
-        .chain(deb_deps(config, &default_deps)?)
-        .chain(extra_override_deps);
+        let build_deps_arch = toolchain_deps(&crate_info.rust_version())
+            .into_iter()
+            .chain(deb_deps(config.allow_prerelease_deps, &default_deps)?)
+            .chain(extra_override_deps);
         if !bins.is_empty() {
-            build_deps.chain(build_deps_extra).collect()
+            build_deps.build_depends_arch.extend(build_deps_arch);
         } else {
             assert!(lib);
             build_deps
-                .chain(build_deps_extra.map(|d| deb_dep_add_nocheck(&d)))
-                .collect()
+                .build_depends_arch
+                .extend(build_deps_arch.map(|d| deb_dep_add_nocheck(&d)));
         }
+        build_deps
     };
     let test_deps: Vec<String> = Some(rustc_dep(&crate_info.rust_version(), false))
         .into_iter()
@@ -948,7 +952,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                     Some(feature)
                 },
                 f_deps,
-                deb_deps(config, &o_deps)?,
+                deb_deps(config.allow_prerelease_deps, &o_deps)?,
                 f_provides.clone(),
                 if feature.is_empty() {
                     recommends.clone()
@@ -1185,6 +1189,12 @@ fn reduce_provides(
     (provides, features_with_deps)
 }
 
+pub(crate) fn toolchain_deps(min_rust_version: &Option<String>) -> Vec<String> {
+    let rustc = rustc_dep(min_rust_version, true);
+    // libstd-rust-dev here is needed to pick up the right arch variant for cross-builds!
+    ["cargo:native".into(), rustc, "libstd-rust-dev".into()].into()
+}
+
 fn rustc_dep(min_ver: &Option<String>, native: bool) -> String {
     let native = if native { ":native" } else { "" };
     if let Some(min_ver) = min_ver {
